==> react-image-annotate_ns_demo-4.0.3.tgz: package/MainLayout/LazyBrushDraw.js <==
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import React from "react";
import CanvasDraw from "./../LazyBrush/index";

var LazyBrushDraw = /*#__PURE__*/function (_React$Component) {
  _inherits(LazyBrushDraw, _React$Component);

  function LazyBrushDraw(props) {
    var _this;

    _classCallCheck(this, LazyBrushDraw);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(LazyBrushDraw).call(this, props));
    _this.state = {
      color: "#ffc600",
      brushRadius: 5,
      lazyRadius: 0
    };
    _this.intervalCode = 0;
    _this.imageData = "";
    return _this;
  }

  _createClass(LazyBrushDraw, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      localStorage.removeItem("savedDrawing"); // console.log("this", this.props.setCanvasRef)
    }
  }, {
    key: "clearImage",
    value: function clearImage() {
      // this.saveableCanvas.clear()
      this.loadableCanvas.clear();
    }
  }, {
    key: "loadImage",
    value: function loadImage() {
      var savedImage = localStorage.getItem("savedDrawing");

      if (savedImage === this.imageData) {
        return;
      }

      this.imageData = savedImage;
      this.loadableCanvas.loadSaveData(savedImage);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      window.clearInterval(this.intervalCode);
    }
  }, {
    key: "render",
    value: function render() {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(CanvasDraw, {
        setCanvasRef: this.props.setCanvasRef,
        brushColor: this.state.color,
        hideGrid: true,
        brushRadius: this.state.brushRadius,
        lazyRadius: this.state.lazyRadius,
        selectedTool: this.props.selectedTool,
        lazyBrush: this.props.lazyBrush,
        lazyBrushClassification: this.props.lazyBrushClassification,
        lazyBrushTags: this.props.lazyBrushTags,
        yPosition: this.props.yPosition,
        xPosition: this.props.xPosition,
        originalClass: this.props.originalClass,
        canvasEl: this.props.canvasEl
      }));
    }
  }]);

  return LazyBrushDraw;
}(React.Component);

export default LazyBrushDraw;

==> react-image-annotate_ns_demo-4.0.13.tgz: package/MainLayout/LazyBrushDraw.js <==
import _classCallCheck from "@babel/runtime/helpers/esm/classCallCheck";
import _createClass from "@babel/runtime/helpers/esm/createClass";
import _possibleConstructorReturn from "@babel/runtime/helpers/esm/possibleConstructorReturn";
import _getPrototypeOf from "@babel/runtime/helpers/esm/getPrototypeOf";
import _inherits from "@babel/runtime/helpers/esm/inherits";
import React from "react";
import CanvasDraw from "./../LazyBrush/index";

var LazyBrushDraw = /*#__PURE__*/function (_React$Component) {
  _inherits(LazyBrushDraw, _React$Component);

  function LazyBrushDraw(props) {
    var _this;

    _classCallCheck(this, LazyBrushDraw);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(LazyBrushDraw).call(this, props));
    _this.state = {
      color: "rgba(255, 195, 0,0.40)",
      brushRadius: 5,
      lazyRadius: 0
    };
    _this.intervalCode = 0;
    _this.imageData = "";
    return _this;
  }

  _createClass(LazyBrushDraw, [{
    key: "componentWillMount",
    value: function componentWillMount() {
      localStorage.removeItem("savedDrawing"); // console.log("this", this.props.setCanvasRef)
    }
  }, {
    key: "clearImage",
    value: function clearImage() {
      // this.saveableCanvas.clear()
      this.loadableCanvas.clear();
    }
  }, {
    key: "loadImage",
    value: function loadImage() {
      var savedImage = localStorage.getItem("savedDrawing");

      if (savedImage === this.imageData) {
        return;
      }

      this.imageData = savedImage;
      this.loadableCanvas.loadSaveData(savedImage);
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      window.clearInterval(this.intervalCode);
    }
  }, {
    key: "render",
    value: function render() {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(CanvasDraw, {
        setCanvasRef: this.props.setCanvasRef,
        brushColor: this.state.color,
        hideGrid: true,
        brushRadius: this.state.brushRadius,
        lazyRadius: this.state.lazyRadius,
        selectedTool: this.props.selectedTool,
        lazyBrush: this.props.lazyBrush,
        lazyBrushClassification: this.props.lazyBrushClassification,
        lazyBrushTags: this.props.lazyBrushTags,
        yPosition: this.props.yPosition,
        xPosition: this.props.xPosition,
        originalClass: this.props.originalClass,
        canvasEl: this.props.canvasEl,
        showTags: this.props.showTags
      }));
    }
  }]);

  return LazyBrushDraw;
}(React.Component);

export default LazyBrushDraw;
